# vodoo knowledge

Manage Odoo Knowledge articles (requires Odoo Enterprise).

<!-- This file is auto-generated by scripts/gen_cli_docs.py. Do not edit manually. -->

## Commands

### list

List knowledge articles.

**Options:**

| Option | Type | Description |
|--------|------|-------------|
| `--name` | TEXT | Filter by article name |
| `--parent` | TEXT | Filter by parent article name |
| `--category` | TEXT | Filter by category (workspace, private, shared) |
| `--limit` | INT | Maximum number of articles (default: 50) |

### show

Show detailed article information.

**Arguments:**

| Argument | Type | Description |
|----------|------|-------------|
| `article_id` | INT | Article ID |

**Options:**

| Option | Type | Description |
|--------|------|-------------|
| `--html` | BOOL | Show raw HTML content instead of markdown |

### comment

Add a comment to an article (visible to followers).

**Arguments:**

| Argument | Type | Description |
|----------|------|-------------|
| `article_id` | INT | Article ID |
| `message` | TEXT | Comment message |

**Options:**

| Option | Type | Description |
|--------|------|-------------|
| `--author` / `-a` | INT | User ID to post as |
| `--no-markdown` | BOOL | Disable markdown to HTML conversion |

### note

Add an internal note to an article.

**Arguments:**

| Argument | Type | Description |
|----------|------|-------------|
| `article_id` | INT | Article ID |
| `message` | TEXT | Note message |

**Options:**

| Option | Type | Description |
|--------|------|-------------|
| `--author` / `-a` | INT | User ID to post as |
| `--no-markdown` | BOOL | Disable markdown to HTML conversion |

### chatter

Show message history/chatter for an article.

**Arguments:**

| Argument | Type | Description |
|----------|------|-------------|
| `article_id` | INT | Article ID |

**Options:**

| Option | Type | Description |
|--------|------|-------------|
| `--limit` | INT | Maximum number of messages |
| `--html` | BOOL | Show raw HTML body instead of plain text |

### attachments

List attachments for an article.

**Arguments:**

| Argument | Type | Description |
|----------|------|-------------|
| `article_id` | INT | Article ID |

### url

Get the web URL for an article.

**Arguments:**

| Argument | Type | Description |
|----------|------|-------------|
| `article_id` | INT | Article ID |

